/*:
 * @target MZ
 * @plugindesc タイマーの色、大きさ、アウトラインをカスタマイズします
 * @help
 * このプラグインを使用すると、タイマーの色、大きさ、アウトラインをカスタマイズできます。
 * 
 * @param textColor
 * @text テキストの色
 * @desc タイマーのテキストの色を変更します。16進数のカラーコードを使用してください。
 * @default #FFFFFF
 * 
 * @param fontSize
 * @text フォントサイズ
 * @desc タイマーのフォントサイズを変更します。
 * @default 32
 * 
 * @param outlineColor
 * @text アウトラインの色
 * @desc タイマーのアウトラインの色を変更します。16進数のカラーコードを使用してください。
 * @default #000000
 * 
 * @param outlineWidth
 * @text アウトラインの幅
 * @desc タイマーのアウトラインの幅を設定します。ピクセル単位です。
 * @default 4
 */

(() => {
    const parameters = PluginManager.parameters('CustomTimer');
    const textColor = parameters['textColor'] || '#FFFFFF';
    const fontSize = Number(parameters['fontSize']) || 32;
    const outlineColor = parameters['outlineColor'] || '#000000';
    const outlineWidth = Number(parameters['outlineWidth']) || 4;

    const _Sprite_Timer_createBitmap = Sprite_Timer.prototype.createBitmap;
    Sprite_Timer.prototype.createBitmap = function() {
        const width = 150;
        const height = 75;
        this.bitmap = new Bitmap(width, height);
        this.bitmap.fontFace = $gameSystem.mainFontFace();
        this.bitmap.fontSize = fontSize;
        this.bitmap.outlineColor = outlineColor;
        this.bitmap.outlineWidth = outlineWidth;
        this.bitmap.textColor = textColor;
        this.updateBitmap();
    };

    // 追加 6/10
    Sprite_Timer.prototype.updateBitmap = function() {
        if (this._seconds !== $gameTimer.seconds()) {
            this._seconds = $gameTimer.seconds();
            this.redraw();
        }
    };

    Sprite_Timer.prototype.redraw = function() {
        const text = this.timerText();
        const width = this.bitmap.width;
        const height = this.bitmap.height;
        this.bitmap.clear();
        this.bitmap.drawText(text, 0, 0, width, height, 'center');
    };

    Sprite_Timer.prototype.timerText = function() {
        return this._seconds.toString().padStart(2, '0');
    };
})();